/*
 * File         : BV_Member.cpp
 * Author       : Tomasz Stachowiak
 * Created      : Thu May 21 19:44:41 1998
 * Revision     : $Revision$
 * Updated      : $Date$
 * Copyright: Northeast Parallel Architectures Center
 *            at Syracuse University 1998
 */

#include <bstring.h>

#include <BVN/Reactor.h>
#include <BVN/Connector.h>
#include <BVN/SOCK_Connector.h>
#include <BVN/SOCK_Library.h>

#include "BV_Svc_Handler.h"

#include "BV_Member.h"

#define BV_PORT 5000

BV_Member::BV_Member() : stream_(0)
{
  display_on_ = 0;
}

BV_Member::BV_Member(SOCK_Stream *stream, uchar id, char *name, int host) 
  : stream_(stream), id_(id), host_(host)
{
  strcpy(name_, name);
  display_on_ = 0;
}

BV_Member::BV_Member(char *name, int host) 
  : host_(host)
{
  strcpy(name_, name);
  stream_ = 0;
  display_on_ = 0;
}

BV_Member::BV_Member(BV_Member *mbr)
{
  id_ = mbr->get_id();
  host_ = mbr->get_host();
  mbr->get_name(name_);
  stream_ = mbr->get_stream();
  display_on_ = 0;
}

void BV_Member::operator= (BV_Member &mbr)
{
  id_ = mbr.get_id();
  host_ = mbr.get_host();
  mbr.get_name(name_);
  stream_ = mbr.get_stream();
}

int BV_Member::connect(Reactor *reactor)
{
  struct sockaddr_in addr;

  BV_Svc_Handler *sh = new BV_Svc_Handler();
  Connector<BV_Svc_Handler, SOCK_Connector> *conn 
    = new Connector<BV_Svc_Handler, SOCK_Connector>(reactor);

  bzero(&addr, sizeof(addr));
  addr.sin_family = AF_INET;
  addr.sin_addr.s_addr = htonl(host_);
  addr.sin_port = htons(BV_PORT);
  if(conn->connect(&addr, sh) == -1)
    {
      stream_ = 0;
      return -1;
    }

  stream_ = sh->peer();
  return 0;
}

void BV_Member::close()
{
  if(stream_ != 0)
    stream_->close();
}

uchar BV_Member::get_id()
{
  return id_;
}

void BV_Member::set_id(uchar id)
{
  id_ = id;
}

void BV_Member::get_name(char *name)
{
  strcpy(name, name_);
}

void BV_Member::set_name(char *name)
{
  strcpy(name_, name);
}

int BV_Member::get_host()
{
  return host_;
}

int BV_Member::get_string(char *str)
{
  char tmp[50];

  strcpy(str, name_);
  SOCK_Library::gethostname(host_, tmp);
  strcat(str, "@");
  strcat(str, tmp);

  return 0;  
}

int BV_Member::send_msg(BV_Message *msg)
{
  return msg->send(stream_);
}

int BV_Member::get_participant(Participant *part)
{
  part->handle = id_;
  part->host = host_;
  strcpy(part->user, name_);

  return 0;
}

SOCK_Stream *BV_Member::get_stream()
{
  return stream_;
}

void BV_Member::set_stream(SOCK_Stream *stream)
{
  stream_ = stream;
}

void BV_Member::set_internal_id(int internal_id)
{
  internal_id_ = internal_id;
}

int BV_Member::get_internal_id()
{
  return internal_id_;
}
